from distutils.core import setup

setup(
	name		= 'kmorinester',
	version		= '1.5.0',
	py_modules	= ['kmorinester'],
	author		= 'Kalil Mori Lopes',
	author_email	= 'kalil.eng@gmail.com',
	url		= '',
	description	= 'A simple printer of nested lists',
)
